@@ -1,4 +1,4 @@
-use crate::{get::Get, put::Put, query::Query};
+use crate::{get::Get, put::Put, query::Query, delete::Delete};
 
 /// Extension trait providing high level implementations of dynamodb requests
 pub trait DynamoDb: rusoto_dynamodb::DynamoDb {
@@ -14,6 +14,10 @@ pub trait DynamoDb: rusoto_dynamodb::DynamoDb {
     fn put<'d, T: Put<'d, Self>>(&'d self, t: T) -> T::Builder {
         t.put(self)
     }
+    /// Perform a put item request
+    fn delete<'d, T: Delete<'d, Self>>(&'d self) -> T::Builder {
+        T::delete(self)
+    }
 }
 
 impl<D: rusoto_dynamodb::DynamoDb> DynamoDb for D {}
